==> bilireq-0.2.3.tar.gz: bilireq-0.2.3/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['bilireq',
 'bilireq.auth',
 'bilireq.bangumi',
 'bilireq.dynamic',
 'bilireq.grpc',
 'bilireq.grpc.dynamic',
 'bilireq.grpc.live',
 'bilireq.grpc.protos.bilibili.account.fission.v1',
 'bilireq.grpc.protos.bilibili.ad.v1',
 'bilireq.grpc.protos.bilibili.api.probe.v1',
 'bilireq.grpc.protos.bilibili.app.archive.middleware.v1',
 'bilireq.grpc.protos.bilibili.app.archive.v1',
 'bilireq.grpc.protos.bilibili.app.card.v1',
 'bilireq.grpc.protos.bilibili.app.dynamic.v1',
 'bilireq.grpc.protos.bilibili.app.dynamic.v2',
 'bilireq.grpc.protos.bilibili.app.interfaces.v1',
 'bilireq.grpc.protos.bilibili.app.listener.v1',
 'bilireq.grpc.protos.bilibili.app.nativeact.v1',
 'bilireq.grpc.protos.bilibili.app.playeronline.v1',
 'bilireq.grpc.protos.bilibili.app.playurl.v1',
 'bilireq.grpc.protos.bilibili.app.resource.privacy.v1',
 'bilireq.grpc.protos.bilibili.app.resource.v1',
 'bilireq.grpc.protos.bilibili.app.show.gateway.v1',
 'bilireq.grpc.protos.bilibili.app.show.popular.v1',
 'bilireq.grpc.protos.bilibili.app.show.rank.v1',
 'bilireq.grpc.protos.bilibili.app.show.region.v1',
 'bilireq.grpc.protos.bilibili.app.space.v1',
 'bilireq.grpc.protos.bilibili.app.splash.v1',
 'bilireq.grpc.protos.bilibili.app.topic.v1',
 'bilireq.grpc.protos.bilibili.app.view.v1',
 'bilireq.grpc.protos.bilibili.app.wall.v1',
 'bilireq.grpc.protos.bilibili.broadcast.message.editor',
 'bilireq.grpc.protos.bilibili.broadcast.message.esports',
 'bilireq.grpc.protos.bilibili.broadcast.message.fission',
 'bilireq.grpc.protos.bilibili.broadcast.message.im',
 'bilireq.grpc.protos.bilibili.broadcast.message.main',
 'bilireq.grpc.protos.bilibili.broadcast.message.note',
 'bilireq.grpc.protos.bilibili.broadcast.message.ogv',
 'bilireq.grpc.protos.bilibili.broadcast.message.ticket',
 'bilireq.grpc.protos.bilibili.broadcast.message.tv',
 'bilireq.grpc.protos.bilibili.broadcast.v1',
 'bilireq.grpc.protos.bilibili.broadcast.v2',
 'bilireq.grpc.protos.bilibili.cheese.gateway.player.v1',
 'bilireq.grpc.protos.bilibili.community.service.dm.v1',
 'bilireq.grpc.protos.bilibili.community.service.govern.v1',
 'bilireq.grpc.protos.bilibili.dynamic.common',
 'bilireq.grpc.protos.bilibili.dynamic.gw',
 'bilireq.grpc.protos.bilibili.dynamic.interfaces.feed.v1',
 'bilireq.grpc.protos.bilibili.gaia.gw',
 'bilireq.grpc.protos.bilibili.im.interfaces.inner_interface.v1',
 'bilireq.grpc.protos.bilibili.im.interfaces.v1',
 'bilireq.grpc.protos.bilibili.im.type',
 'bilireq.grpc.protos.bilibili.live.app.room.v1',
 'bilireq.grpc.protos.bilibili.live.general.interfaces.v1',
 'bilireq.grpc.protos.bilibili.main.common.arch.doll.v1',
 'bilireq.grpc.protos.bilibili.main.community.reply.v1',
 'bilireq.grpc.protos.bilibili.metadata',
 'bilireq.grpc.protos.bilibili.metadata.device',
 'bilireq.grpc.protos.bilibili.metadata.fawkes',
 'bilireq.grpc.protos.bilibili.metadata.locale',
 'bilireq.grpc.protos.bilibili.metadata.network',
 'bilireq.grpc.protos.bilibili.metadata.parabox',
 'bilireq.grpc.protos.bilibili.metadata.restriction',
 'bilireq.grpc.protos.bilibili.pangu.gallery.v1',
 'bilireq.grpc.protos.bilibili.pgc.gateway.player.v1',
 'bilireq.grpc.protos.bilibili.pgc.gateway.player.v2',
 'bilireq.grpc.protos.bilibili.pgc.service.premiere.v1',
 'bilireq.grpc.protos.bilibili.polymer.contract',
 'bilireq.grpc.protos.bilibili.polymer.demo',
 'bilireq.grpc.protos.bilibili.polymer.list',
 'bilireq.grpc.protos.bilibili.rpc',
 'bilireq.grpc.protos.bilibili.tv.interfaces.dm.v1',
 'bilireq.grpc.protos.bilibili.vega.deneb.v1',
 'bilireq.grpc.protos.bilibili.web.interfaces.v1',
 'bilireq.grpc.protos.pgc.biz',
 'bilireq.grpc.protos.pgc.gaetway.vega.v1',
 'bilireq.grpc.utils',
 'bilireq.live',
 'bilireq.login',
 'bilireq.user',
 'bilireq.utils',
 'bilireq.video']

package_data = \
{'': ['*'],
 'bilireq.grpc': ['protos/bilibili/im/interfaces/inner-interface/v1/*']}

install_requires = \
['grpcio>=1.46.3,<2.0.0',
 'httpx>=0.23.0,<0.24.0',
 'protobuf==3.20.1',
 'rsa>=4.8,<5.0']

extras_require = \
{':extra == "qrcode"': ['qrcode[pil]>=7.3.1,<8.0.0']}

setup_kwargs = {
    'name': 'bilireq',
    'version': '0.2.3',
    'description': '',
    'long_description': None,
    'author': 'SK-415',
    'author_email': '2967923486@qq.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)

==> bilireq-0.2.4.tar.gz: bilireq-0.2.4/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['bilireq',
 'bilireq.auth',
 'bilireq.bangumi',
 'bilireq.dynamic',
 'bilireq.grpc',
 'bilireq.grpc.dynamic',
 'bilireq.grpc.live',
 'bilireq.grpc.protos.bilibili.account.fission.v1',
 'bilireq.grpc.protos.bilibili.ad.v1',
 'bilireq.grpc.protos.bilibili.api.player.v1',
 'bilireq.grpc.protos.bilibili.api.probe.v1',
 'bilireq.grpc.protos.bilibili.app.archive.middleware.v1',
 'bilireq.grpc.protos.bilibili.app.archive.v1',
 'bilireq.grpc.protos.bilibili.app.card.v1',
 'bilireq.grpc.protos.bilibili.app.dynamic.v1',
 'bilireq.grpc.protos.bilibili.app.dynamic.v2',
 'bilireq.grpc.protos.bilibili.app.interfaces.v1',
 'bilireq.grpc.protos.bilibili.app.nativeact.v1',
 'bilireq.grpc.protos.bilibili.app.playeronline.v1',
 'bilireq.grpc.protos.bilibili.app.playurl.v1',
 'bilireq.grpc.protos.bilibili.app.resource.privacy.v1',
 'bilireq.grpc.protos.bilibili.app.resource.v1',
 'bilireq.grpc.protos.bilibili.app.show.gateway.v1',
 'bilireq.grpc.protos.bilibili.app.show.popular.v1',
 'bilireq.grpc.protos.bilibili.app.show.rank.v1',
 'bilireq.grpc.protos.bilibili.app.show.region.v1',
 'bilireq.grpc.protos.bilibili.app.space.v1',
 'bilireq.grpc.protos.bilibili.app.splash.v1',
 'bilireq.grpc.protos.bilibili.app.topic.v1',
 'bilireq.grpc.protos.bilibili.app.view.v1',
 'bilireq.grpc.protos.bilibili.app.wall.v1',
 'bilireq.grpc.protos.bilibili.broadcast.message.editor',
 'bilireq.grpc.protos.bilibili.broadcast.message.esports',
 'bilireq.grpc.protos.bilibili.broadcast.message.fission',
 'bilireq.grpc.protos.bilibili.broadcast.message.im',
 'bilireq.grpc.protos.bilibili.broadcast.message.main',
 'bilireq.grpc.protos.bilibili.broadcast.message.note',
 'bilireq.grpc.protos.bilibili.broadcast.message.ogv',
 'bilireq.grpc.protos.bilibili.broadcast.message.ticket',
 'bilireq.grpc.protos.bilibili.broadcast.message.tv',
 'bilireq.grpc.protos.bilibili.broadcast.v1',
 'bilireq.grpc.protos.bilibili.broadcast.v2',
 'bilireq.grpc.protos.bilibili.cheese.gateway.player.v1',
 'bilireq.grpc.protos.bilibili.community.interfacess.biligram.v1',
 'bilireq.grpc.protos.bilibili.community.service.dm.v1',
 'bilireq.grpc.protos.bilibili.community.service.govern.v1',
 'bilireq.grpc.protos.bilibili.dagw.component.avatar.common',
 'bilireq.grpc.protos.bilibili.dagw.component.avatar.v1',
 'bilireq.grpc.protos.bilibili.dynamic.common',
 'bilireq.grpc.protos.bilibili.dynamic.gw',
 'bilireq.grpc.protos.bilibili.dynamic.interfaces.campus.v1',
 'bilireq.grpc.protos.bilibili.dynamic.interfaces.feed.v1',
 'bilireq.grpc.protos.bilibili.gaia.gw',
 'bilireq.grpc.protos.bilibili.im.interfaces.inner_interface.v1',
 'bilireq.grpc.protos.bilibili.im.interfaces.v1',
 'bilireq.grpc.protos.bilibili.im.type',
 'bilireq.grpc.protos.bilibili.live.app.room.v1',
 'bilireq.grpc.protos.bilibili.live.general.interfaces.v1',
 'bilireq.grpc.protos.bilibili.main.common.arch.doll.v1',
 'bilireq.grpc.protos.bilibili.main.community.reply.v1',
 'bilireq.grpc.protos.bilibili.metadata',
 'bilireq.grpc.protos.bilibili.metadata.device',
 'bilireq.grpc.protos.bilibili.metadata.fawkes',
 'bilireq.grpc.protos.bilibili.metadata.locale',
 'bilireq.grpc.protos.bilibili.metadata.network',
 'bilireq.grpc.protos.bilibili.metadata.parabox',
 'bilireq.grpc.protos.bilibili.metadata.restriction',
 'bilireq.grpc.protos.bilibili.pagination',
 'bilireq.grpc.protos.bilibili.pangu.gallery.v1',
 'bilireq.grpc.protos.bilibili.pangu.gallery.v1.openplatform.apiserver.v1alpha1',
 'bilireq.grpc.protos.bilibili.pgc.gateway.player.v1',
 'bilireq.grpc.protos.bilibili.pgc.gateway.player.v2',
 'bilireq.grpc.protos.bilibili.pgc.gateway.player.v3',
 'bilireq.grpc.protos.bilibili.pgc.service.premiere.v1',
 'bilireq.grpc.protos.bilibili.playershared',
 'bilireq.grpc.protos.bilibili.polymer.app.search.v1',
 'bilireq.grpc.protos.bilibili.polymer.community.govern.v1',
 'bilireq.grpc.protos.bilibili.polymer.contract',
 'bilireq.grpc.protos.bilibili.polymer.demo',
 'bilireq.grpc.protos.bilibili.polymer.list',
 'bilireq.grpc.protos.bilibili.relation.interfaces',
 'bilireq.grpc.protos.bilibili.render',
 'bilireq.grpc.protos.bilibili.rpc',
 'bilireq.grpc.protos.bilibili.tv.interfaces.dm.v1',
 'bilireq.grpc.protos.bilibili.vega.deneb.v1',
 'bilireq.grpc.protos.bilibili.web.interfaces.v1',
 'bilireq.grpc.protos.bilibili.web.space.v1',
 'bilireq.grpc.protos.pgc.biz',
 'bilireq.grpc.protos.pgc.gateway.vega.v1',
 'bilireq.grpc.utils',
 'bilireq.live',
 'bilireq.login',
 'bilireq.user',
 'bilireq.utils',
 'bilireq.video']

package_data = \
{'': ['*'],
 'bilireq.grpc': ['protos/bilibili/app/listener/v1/*',
                  'protos/bilibili/im/interfaces/inner-interface/v1/*']}

install_requires = \
['grpcio>=1.49.1,<2.0.0',
 'httpx>=0.23.0,<0.24.0',
 'protobuf>=4.21.7,<5.0.0',
 'rsa>=4.9,<5.0']

extras_require = \
{':extra == "qrcode"': ['qrcode[pil]>=7.3.1,<8.0.0']}

setup_kwargs = {
    'name': 'bilireq',
    'version': '0.2.4',
    'description': '',
    'long_description': 'None',
    'author': 'SK-415',
    'author_email': '2967923486@qq.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
